.. role:: header_no_toc
  :class: class_header_no_toc

.. title:: Welcome to sdss_access's documentation!

:tocdepth: 2

.. rubric:: :header_no_toc:`Welcome to sdss_access's documentation!`

This is the Sphinx documentation for the SDSS Python product sdss_access

Introduction
------------

* :ref:`What's new in sdss_access? <changelog>`
* :ref:`Installation <install>`
* :ref:`Introduction to sdss_access <intro>`
* :ref:`sdss-access path definitions <paths>`

Reference
---------

.. toctree::
   :maxdepth: 1

   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
